//------------------------------------------------------------------
//
//------------------------------------------------------------------
#property indicator_chart_window
#property indicator_buffers 2
#property indicator_color1 LimeGreen
#property indicator_color2 Orange

extern double WickPercentMin   = 25;
extern double WickPercentMax   = 50;
extern bool   alertsOn         = false;
extern bool   alertsOnCurrent  = true;
extern bool   alertsMessage    = true;
extern bool   alertsPushNotif  = false;
extern bool   alertsSound      = false;
extern bool   alertsEmail      = false;

double up[];
double dn[];

//------------------------------------------------------------------
//
//------------------------------------------------------------------
//
//
//
//
//

int init() 
{
   SetIndexBuffer(0,up); SetIndexStyle(0,DRAW_HISTOGRAM);
   SetIndexBuffer(1,dn); SetIndexStyle(1,DRAW_HISTOGRAM);
   return (0);
}

//------------------------------------------------------------------
//
//------------------------------------------------------------------
//
//
//
//
//

int start()
{
   int counted_bars=IndicatorCounted();
      if(counted_bars<0) return(-1);
      if(counted_bars>0) counted_bars--;
         int limit = MathMin(Bars-counted_bars,Bars-1);
         
         //
         //
         //
         //
         //

   for (int i=limit; i>=0; i--)   
   {
      double bar   = High[i]-Low[i];
      double wick  = bar-MathAbs(Open[i]-Close[i]);
         up[i] = EMPTY_VALUE;
         dn[i] = EMPTY_VALUE;
         if ((wick/bar)>=(WickPercentMin/100.0) && (wick/bar)<=(WickPercentMax/100.0))
            {
               if (Close[i]>Open[i])
                     { up[i] = High[i]; dn[i] = Low[i]; }
               else  { dn[i] = High[i]; up[i] = Low[i]; }
            }               
   }
   manageAlerts();
   return (0);   
}

//-------------------------------------------------------------------
//                                                                  
//-------------------------------------------------------------------
//
//
//
//
//

void manageAlerts()
{
   if (alertsOn)
   {
      if (alertsOnCurrent)
           int whichBar = 0;
      else     whichBar = 1;
      static datetime lastTime1 = 0;
      static string   lastMess1 = "";
         if (up[whichBar] != EMPTY_VALUE && dn[whichBar] != EMPTY_VALUE) doAlert(lastMess1,lastTime1," - wick in required range");
   }
}

//
//
//
//
//

void doAlert(string& previousAlert, datetime& previousTime, string doWhat)
{
   string message;
   
   if (previousAlert != doWhat || previousTime != Time[0]) {
       previousAlert  = doWhat;
       previousTime   = Time[0];

       //
       //
       //
       //
       //

       message =  StringConcatenate(Symbol()," at ",TimeToStr(TimeLocal(),TIME_SECONDS)," percent wick alert ",doWhat);
          if (alertsMessage)   Alert(message);
          if (alertsEmail)     SendMail(StringConcatenate(Symbol(),"percent wick"),message);
          if (alertsPushNotif) SendNotification(StringConcatenate(Symbol(),"percent wick"+message));
          if (alertsSound)     PlaySound("alert2.wav");
   }
}

